/*
** Class:  LotROLinux.JoinWorldQueue
** Author: Alan Jackson
** Date:   6th June 2007
**
** Class to authenticate the user account & password details
** for the game Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using System;
using System.IO;
using System.Net;
using System.Xml;
using System.Collections.Generic; 

namespace LotROLinux
{
	public class AuthenticateUser
	{
		private const string keyConfigFile = "GLSAuthServer.config";
		private const string keySubscriptions = "Subscriptions";
		private const string keyGame = "Game";
		private const string keyName = "Name";
		private const string keyDesc = "Description";
		private const string keyTicket = "Ticket";
		private const string keyStatus = "Status";
		private const string keyActive = "Active";
		private const string messNoError = "No error";
		private const string messUserPasswd = "Account details incorrect";
		private const string messServerError = "Server not found - may be down";
		private const string messStatusError = "Account marked as not active";
		private const string header = "SOAPAction: \"http://www.turbine.com/SE/GLS/LoginAccount\"";
		private const string bodyDataTemplate = "<?xml version=\"1.0\" encoding=\"utf-8\"?><soap:Envelope xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:soap=\"http://schemas.xmlsoap.org/soap/envelope/\"><soap:Body><LoginAccount xmlns=\"http://www.turbine.com/SE/GLS\"><username>{0}</username><password>{1}</password><additionalInfo></additionalInfo></LoginAccount></soap:Body></soap:Envelope>";
		
		private List<Game> gameList;
		private string valTicket;
		private string messError;
		private bool flagAuthSuccess;
		private bool activeAcc;

		public AuthenticateUser(string urlLoginServer, string name,
		                        string password, string game,
								string homeDir, string configDir)
		{
			gameList = new List<Game>();

			System.Net.ServicePointManager.CertificatePolicy = new SecureHTTPOverride();

			string bodyData = String.Format(bodyDataTemplate, name, password);
				
			try
			{
				WebRequest authRequest = WebRequest.Create(urlLoginServer);

				authRequest.Method = "POST";
				authRequest.ContentType = "text/xml; charset=utf-8";
			
				authRequest.ContentLength = bodyData.Length;
				authRequest.Headers.Add(header);

				Stream bodyStream = authRequest.GetRequestStream();
				StreamWriter bodyStreamWrite = new StreamWriter(bodyStream);

				bodyStreamWrite.Write(bodyData);
				
				bodyStreamWrite.Flush();

				bodyStreamWrite.Close();
			
				bodyStream.Close();
				
				WebResponse authResponse = authRequest.GetResponse();

				XmlDocument xDoc = new XmlDocument();
		
				xDoc.Load(authResponse.GetResponseStream());

				xDoc.Save(String.Format("{0}{1}{2}", homeDir, configDir, keyConfigFile));
				
				authResponse.Close();

				XmlNodeList games = xDoc.GetElementsByTagName(keySubscriptions)[0].ChildNodes;

				activeAcc = false;
				
				for (int loop = 0; loop < games.Count; loop++)
				{
					ProcessGame(games[loop].ChildNodes, game);

				}

				valTicket = xDoc.GetElementsByTagName(keyTicket)[0].InnerText;
				
                if (activeAcc)
                {
				    messError = messNoError;
				    flagAuthSuccess = true;
                } else {
				    messError = messStatusError;
				    flagAuthSuccess = false;
                }
			}
			catch (WebException e)
			{
				if (e.Message.ToUpper().Contains("ERROR: (500) INTERNAL SERVER ERROR"))
				{
					messError = messUserPasswd;

					XmlDocument xDoc = new XmlDocument();
		
					xDoc.Load(e.Response.GetResponseStream());
					xDoc.Save(String.Format("{0}{1}{2}", homeDir, configDir, keyConfigFile));
				} else {
					messError = messServerError;
				}

				flagAuthSuccess = false;
			}
			catch
			{
				messError = messServerError;
				flagAuthSuccess = false;
			}
		}

		private void ProcessGame(XmlNodeList game, string gameCode)
		{
			int loop;
			bool validGame;
			string gameName;
			string gameDesc;

			loop = 0;
			validGame = true;
			gameName = "";
			gameDesc = "";

			while (loop < game.Count)
			{
				if (game[loop].Name == keyGame)
				{
					if (game[loop].InnerText == gameCode)
					{
						loop++;
					} else {
						validGame = false;
						loop = game.Count;
					}
				} else if (game[loop].Name == keyStatus) {
					if (game[loop].InnerText == keyActive)
					{
						loop++;
					} else {
						validGame = false;
						loop = game.Count;
					}
				} else if (game[loop].Name == keyName) {
					gameName = game[loop].InnerText;
					loop++;
				} else if (game[loop].Name == keyDesc) {
					gameDesc = game[loop].InnerText;
					loop++;
				} else {
					loop++;
				}
			}

			if (validGame)
			{
				activeAcc = true;

				Game tempGame = new Game(gameName, gameDesc);
				gameList.Add(tempGame);
			}
		}
		
		public List<Game> GetGameList()
		{
			return gameList;
		}
		
		public string GetTicket()
		{
			return valTicket;
		}
		
		public string GetErrorMessage()
		{
			return messError;
		}

		public bool isAuthenticated()
		{
			return flagAuthSuccess;
		}
	}
}
