/*
** Class:  LotROLinux.BaseConfig
** Author: Alan Jackson
** Date:   6th June 2007
**
** Class to process the launcher configuration file
** (TurbineLauncher.exe.config) for the game
** Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using System;
using System.IO;
using System.Xml;

namespace LotROLinux
{
	public class BaseConfig
	{
		private const string keyAppSettings = "appSettings";
		private const string attribKeyName = "key";
		private const string keyGLSDataCentreService = "Launcher.DataCenterService.GLS";
		private const string keyGameName = "DataCenter.GameName";
		
		private string valGLSDataCentreService;
		private string valGameName;
		private bool flagConfigOK;

		public BaseConfig(string configFile)
		{
			valGLSDataCentreService = "";
			valGameName = "";

			XmlDocument xDoc = new XmlDocument();
		
			try
			{
				xDoc.Load(configFile);
			
				XmlNodeList appSettings = xDoc.GetElementsByTagName(keyAppSettings)[0].ChildNodes;
	
				foreach (XmlNode appSetting in appSettings)
				{
					string tempKey = "";

					foreach (XmlNode setAttrib in appSetting.Attributes)
					{
						if (setAttrib.Name.ToString() == attribKeyName)
						{
							tempKey = setAttrib.InnerText;
						} else {
							switch (tempKey)
							{
								case keyGLSDataCentreService:
									valGLSDataCentreService = setAttrib.InnerText;
									break;
								case keyGameName:
									valGameName = setAttrib.InnerText;
									break;
							}
						}
					}
				}
				
				flagConfigOK = true;
			}
			catch
			{
				flagConfigOK = false;
			}
		}
		
		public string GetGLSDataCentreService()
		{
			return valGLSDataCentreService;
		}
		
		public string GetGameName()
		{
			return valGameName;
		}
		
		public bool IsLauncherConfigOK()
		{
			return flagConfigOK;
		}
	}
}
