/*
** Class:  LotROLinux.DetermineGame
** Author: Alan Jackson
** Date:   9th January 2008
**
** Class to determine which icons, images and text to use
** in the launcher for the games Dungeons & Dragons Online or
** Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using System;

namespace LotROLinux
{
	public class DetermineGame
	{
		private const string lotroConfig = "/TurbineLauncher.exe.config";
		private const string ddoConfig = "/dndlauncher.exe.config";
        private const string ddo = "DDO";
        private const string lotro = "LotRO";
        private const string fileICO = "Linux.ico";
        private const string filePNG = "Linux.png";
        private const string lotroTitle = "Lord of the Rings Online - "
				+ "Launcher for Linux";
        private const string ddoTitle = "Dungeon &amp; Dragons Online - "
				+ "Launcher for Linux";
        private const string lotroTitleTest = "Lord of the Rings Online (Test) - "
				+ "Launcher for Linux";
        private const string ddoTitleTest = "Dungeon &amp; Dragons Online (Test) - "
				+ "Launcher for Linux";
		
        private string icoFile;
        private string pngFile;
		private string configFile;
		private string configFileAlt;
		private string title;

		public DetermineGame()
		{
		}

		public void GetSettings(bool usingDND, bool usingTest)
		{
			if (usingDND)
			{
				configFile = lotroConfig;
				configFileAlt = ddoConfig;
		        icoFile = String.Format("{0}{1}", ddo, fileICO);
		        pngFile = String.Format("{0}{1}", ddo, filePNG);

				if (usingTest)
				{
					title = ddoTitleTest;
				} else {
					title = ddoTitle;
				}
			} else {
				configFile = lotroConfig;
				configFileAlt = lotroConfig;
		        icoFile = String.Format("{0}{1}", lotro, fileICO);
		        pngFile = String.Format("{0}{1}", lotro, filePNG);

				if (usingTest)
				{
					title = lotroTitleTest;
				} else {
					title = lotroTitle;
				}
			}
		}

		public string GetConfigFile()
		{
			return configFile;
		}

		public string GetConfigFileAlt()
		{
			return configFileAlt;
		}

        public string GetICOFile()
        {
        	return icoFile;
        }
        
        public string GetPNGFile()
        {
        	return pngFile;
        }
        
        public string GetTitle()
        {
        	return title;
        }
	}
}
