/*
** Class:  LotROLinux.LanguageConfig
** Author: Alan Jackson
** Date:   6th June 2007
**
** Class to determine which languages are available
** for the game Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using System;
using System.IO;
using System.Collections;
using System.Text.RegularExpressions;
using System.Collections.Generic; 

namespace LotROLinux
{
	public class LanguageConfig
	{
		private const string fileName = "client_local_";
		private const string fileExt = ".dat";
		private const string keyLang = "lang";
		
		private List<Language> langList;
		private bool flagLangFound;

		public LanguageConfig(string runDir)
		{
			flagLangFound = false;

			try
			{
				DirectoryInfo gameDir = new DirectoryInfo(runDir);
				FileInfo[] langFiles = gameDir.GetFiles(String.Format("{0}*{1}", fileName, fileExt));
			
				langList = new List<Language>();

				int count = 0;
		
				foreach (FileInfo langFile in langFiles) 
				{
					Match m = Regex.Matches(langFile.Name,
						String.Format("({0})(?<{1}>.*)({2})",
							fileName, keyLang, fileExt))[0];

					string tempName = m.Groups[keyLang].ToString();
					
					Language tempLang = new Language(tempName.ToUpper());
					langList.Add(tempLang);
					count++;
			
					flagLangFound = true;
				}
			} catch {
				flagLangFound = false;
			}
		}
		
		public List<Language> GetLanguages()
		{
			return langList;
		}

		public bool IsLanguageFound()
		{
			return flagLangFound;
		}
	}
}
