/*
** Class:  LotROLinux.Realm
** Author: Alan Jackson
** Date:   6th June 2007
**
** Class to hold details about the realms available
** for the game Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using System;
using System.IO;
using System.Net;
using System.Xml;
using System.Text.RegularExpressions;

namespace LotROLinux
{
	public class Realm
	{
		private const string keyLoginServer = "loginservers";
		private const string keyQueueURL = "queueurls";
		private const string keyConfigFile = "server.config";
		private const string keyServing = "nowservingqueuenumber";

		private string name;
		private string urlChatServer;
		private string urlServerStatus;
		private string valLoginServer;
		private string valQueueURL;
		private string valServing;
		private bool flagRealmAvailable;
		
		public Realm(string name, string urlChatServer, string urlServerStatus)
		{
			this.name = name;
			this.urlChatServer = urlChatServer;
			this.urlServerStatus = urlServerStatus;

			flagRealmAvailable = false;
		}

		public void CheckRealm(bool useDND, string homeDir, string configDir)
		{
			try
			{
				string[] listQueue;
				string[] listLogin;
				int lenLogin;
				int lenQueue;

				WebRequest confRequest = WebRequest.Create (urlServerStatus);
			
				WebResponse confResponse = confRequest.GetResponse ();

				XmlDocument xDoc = new XmlDocument();
		
				xDoc.Load(confResponse.GetResponseStream ());

				xDoc.Save(String.Format("{0}{1}{2}", homeDir, configDir, keyConfigFile));

				confResponse.Close();

				if (!useDND)
				{
					valServing = xDoc.GetElementsByTagName(keyServing)[0].InnerText;
				}

				listLogin = Regex.Split(xDoc.GetElementsByTagName(keyLoginServer)[0]
					.InnerText,";");
				lenLogin = listLogin.Length - 1;
				if (listLogin[lenLogin] == null)
				{
					lenLogin--;
				}

				if (useDND)
				{
					lenQueue = lenLogin;
					listQueue = null;
				} else {
					listQueue = Regex.Split(xDoc.GetElementsByTagName(keyQueueURL)[0]
						.InnerText,";"); 
					lenQueue = listQueue.Length - 1;
					if (listQueue[lenQueue] == null)
					{
						lenQueue--;
					}
				}

				Random rnd = new Random(System.DateTime.Now.Millisecond);
				int rndLogin;
				int rndQueue;
				
				if (lenLogin != lenQueue)
				{
					rndLogin = rnd.Next(lenLogin);
					rndQueue = rnd.Next(lenQueue);
				} else {
					rndLogin = rnd.Next(lenLogin);
					rndQueue = rndLogin;
				}

				valLoginServer = listLogin[rndLogin];

				if (useDND)
				{
					valQueueURL = "";
				} else {
					valQueueURL = listQueue[rndQueue];
				}
				
				flagRealmAvailable = true;
			}
			catch
			{
				flagRealmAvailable = false;
			}
		
		}

		public string ServerName
		{
			get { return name; }
		}
		
		public string ChatServerURL
		{
			get { return urlChatServer; }
		}
		
		public string ServerStatusURL
		{
			get { return urlServerStatus; }
		}
		
		public string LoginServer
		{
			get { return (flagRealmAvailable ? valLoginServer : ""); }
		}
		
		public string QueueURL
		{
			get { return (flagRealmAvailable ? valQueueURL : ""); }
		}

		public string NowServing
		{
			get { return valServing; }
		}
		
		public bool IsRealmAvailable
		{
			get { return flagRealmAvailable; }
		}
	}
}
